#!/bin/bash

PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin'

ALLOW_LAN_IN_TCP=''
ALLOW_LAN_IN_UDP='123,53'
DROP_IN_TCP='53,111,389,636,2812,4369,5038,5280,6789'
DROP_IN_UDP='53,111,6050'
LOCAL_NETWORKS='10.0.0.0/8,100.64.0.0/10,172.16.0.0/12,192.168.0.0/16'


## get a sip-rtp port for scan from a portal
if [ -f '/rw2/etc/callweaver/rtp-wms.conf' ]; then
  RTP_START="$(awk -F '=' '/rtpstart=/{print $2}' /rw2/etc/callweaver/rtp-wms.conf 2> /dev/null)"
  if [ "${RTP_START}" ]; then
    RTP_PORT=$((RTP_START-1))
  else
    RTP_PORT='10001'
  fi
fi


#----------------------
## cleanup rules
#----------------------
iptables -F
iptables -X
iptables -F -t nat
iptables -X -t nat


#----------------------
## ALLOWLAN filter
#----------------------
iptables -N ALLOWLAN
iptables -A ALLOWLAN ! -i lo --src ${LOCAL_NETWORKS} -j ACCEPT


#----------------------
## LOGDROP filter
#----------------------
iptables -N LOGDROP
iptables -A LOGDROP -m limit --limit 10/min -j LOG --log-level debug --log-prefix "IPTABLES DROP:"
iptables -A LOGDROP -j DROP


#----------------------
## INVALID filter
#----------------------
iptables -N INVALID
iptables -A INVALID -m limit --limit 10/min -j LOG --log-level debug --log-prefix "IPTABLES DROP (INVALID):"
iptables -A INVALID -j DROP


#----------------------
## TCPREJECT filter
#----------------------
iptables -N TCPREJECT
iptables -A TCPREJECT -m limit --limit 10/min -j LOG --log-level debug --log-prefix "IPTABLES REJECT:"
iptables -A TCPREJECT -p tcp -j REJECT --reject-with tcp-reset


#----------------------
## INPUT filter
#----------------------
# allow from interface localhost, remote support
iptables -A INPUT -i lo -j ACCEPT
iptables -A INPUT -i tun0 -j ACCEPT

# allow ports from local networks
[ "${ALLOW_LAN_IN_TCP}" ] && iptables -A INPUT ! -i lo -p tcp -m multiport --dport ${ALLOW_LAN_IN_TCP} -j ALLOWLAN
[ "${ALLOW_LAN_IN_UDP}" ] && iptables -A INPUT ! -i lo -p udp -m multiport --dport ${ALLOW_LAN_IN_UDP} -j ALLOWLAN

# drop specific ports
[ "${DROP_IN_TCP}" ] && iptables -A INPUT ! -i lo -p tcp -m multiport --dport ${DROP_IN_TCP} -j TCPREJECT
[ "${DROP_IN_UDP}" ] && iptables -A INPUT ! -i lo -p udp -m multiport --dport ${DROP_IN_UDP} -j LOGDROP

# accept related,established connections
iptables -A INPUT ! -i lo -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT

## dos protection for ssh
iptables -A INPUT ! -i lo -p tcp -m multiport --dport 22,2222 -m conntrack --ctstate NEW -m recent --set --name SSH --rsource
iptables -A INPUT ! -i lo -p tcp -m multiport --dport 22,2222 -m recent --update --seconds  60 --hitcount  3 --name SSH --rsource -j LOGDROP
iptables -A INPUT ! -i lo -p tcp -m multiport --dport 22,2222 -m recent --update --seconds 300 --hitcount 15 --name SSH --rsource -j LOGDROP
## dos protection for port http\https
iptables -A INPUT ! -i lo -p tcp --dport  80 -m conntrack --ctstate NEW -m recent --set --name HTTP --rsource
iptables -A INPUT ! -i lo -p tcp --dport  80 -m recent --update --seconds  1 --hitcount 150 --name HTTP --rsource -j LOGDROP
iptables -A INPUT ! -i lo -p tcp --dport  80 -m recent --update --seconds 10 --hitcount 200 --name HTTP --rsource -j LOGDROP
iptables -A INPUT ! -i lo -p tcp --dport  80 -m recent --update --seconds 30 --hitcount 255 --name HTTP --rsource -j LOGDROP
iptables -A INPUT ! -i lo -p tcp --dport 443 -m conntrack --ctstate NEW -m recent --set --name HTTPS --rsource
iptables -A INPUT ! -i lo -p tcp --dport 443 -m recent --update --seconds  1 --hitcount 150 --name HTTPS --rsource -j LOGDROP
iptables -A INPUT ! -i lo -p tcp --dport 443 -m recent --update --seconds 10 --hitcount 200 --name HTTPS --rsource -j LOGDROP
iptables -A INPUT ! -i lo -p tcp --dport 443 -m recent --update --seconds 30 --hitcount 255 --name HTTPS --rsource -j LOGDROP
### dos protection for NTP
iptables -A INPUT ! -i lo -p udp --dport 123 -m recent --set --name NTP --rsource
iptables -A INPUT ! -i lo -p udp --dport 123 -m recent --update --seconds  1 --hitcount 100 --name NTP --rsource -j LOGDROP
iptables -A INPUT ! -i lo -p udp --dport 123 -m recent --update --seconds 10 --hitcount 150 --name NTP --rsource -j LOGDROP
iptables -A INPUT ! -i lo -p udp --dport 123 -m recent --update --seconds 30 --hitcount 250 --name NTP --rsource -j LOGDROP


#----------------------
## FORWARD filter
#----------------------
# drop invalid pakages
iptables -A FORWARD ! -i lo -m state --state INVALID -j INVALID


#----------------------
## PREROUTING nat
#----------------------
iptables -t nat -N UDP-SIP
iptables -t nat -A UDP-SIP -p udp --dport ${RTP_PORT} -j REDIRECT --to-port 5060
iptables -t nat -A UDP-SIP -j RETURN
iptables -t nat -A PREROUTING ! -i lo -p udp -j UDP-SIP


#----------------------
## Load custom settings
#----------------------
[ -f "/etc/default/iptables" ] && source /etc/default/iptables
