#!/bin/bash

[ -f '/etc/default/rsyslog' ] && source /etc/default/rsyslog
CONF_FILE='/etc/rsyslog.d/09-override-udp.conf'

if [ "${UDP}" -eq '0' ]; then
	[ -f "${CONF_FILE}" ] && rm -f ${CONF_FILE}
	exit 0
fi

WMS_VER="$(dpkg -l wms-interface-sqlite3 | awk '/wms-interface-sqlite3/{print $3}')"
declare -a WMS_VER_SPLIT=(${WMS_VER//./ })
LOG_SERVER="pbxlogging${WMS_VER_SPLIT[0]}-${WMS_VER_SPLIT[1]}.wildix.com"

if [ -z "${WMS_VER}" ]; then
	systemd-cat -t "${0##*/}" -p "err" <<< "ERROR: wms version is unknown. exit."
	exit
else
	systemd-cat -t "${0##*/}" -p "notice" <<< "rsyslog is working in UDP mode"
fi

cat << EOF > ${CONF_FILE}
# install in the PBX

template(name="json-template" type="list") {
    constant(value="{")
    constant(value="\"@version\":\"1")
    constant(value="\",\"wms-version\":\"${WMS_VER}")
    constant(value="\",\"host\":\"")      property(name="hostname")
    constant(value="\",\"severity\":\"")  property(name="syslogseverity-text")
    constant(value="\",\"facility\":\"")  property(name="syslogfacility-text")
    constant(value="\",\"message\":\"")   property(name="msg" format="json")
    constant(value="\",\"program\":\"")   property(name="programname" format="json")
    #constant(value="\",\"app-name\":\"")  property(name="app-name" format="json")
    constant(value="\",\"procid\":\"")    property(name="procid")
    #constant(value="\",\"msgid\":\"")     property(name="msgid")
    constant(value="\",\"time\":\"")      property(name="timegenerated" dateFormat="rfc3339")
    constant(value="\",\"tag\":\"")       property(name="syslogtag" format="json")

    #constant(value="\",\"myhostname\":\"")       property(name="\$myhostname" format="json")
    #constant(value="\",\"inputname\":\"") property(name="inputname" format="json")
    #constant(value="\",\"syslogpriority\":\"")      property(name="syslogpriority-text")
    #constant(value="\",\"syslogfacility\":\"")  property(name="syslogfacility")
    #constant(value="\",\"syslogseverity\":\"")  property(name="syslogseverity")
    #constant(value="\",\"priority\":\"")  property(name="syslogpriority")
    #constant(value="\",\"pri\":\"")       property(name="pri-text")
    #constant(value="\",\"pri-int\":\"")       property(name="pri")
    #constant(value="\",\"iut\":\"")       property(name="iut" format="json")
    #constant(value="\",\"protocol-version\":\"")       property(name="protocol-version" format="json")
    #constant(value="\",\"structured-data\":\"")       property(name="structured-data" format="json")
    #constant(value="\",\"rawmsg\":\"")   property(name="rawmsg" format="json")
    #constant(value="\",\"rawmsg-after-pri\":\"")   property(name="rawmsg-after-pri" format="json")
    #constant(value="\",\"fromhost\":\"") property(name="fromhost")
    #constant(value="\",\"fromhost-ip\":\"") property(name="fromhost-ip")
    constant(value="\"}\n")
}

template(name="json-lua-debug" type="list") {
    constant(value="{")
    constant(value="\"@version\":\"1")
    constant(value="\",\"wms-version\":\"${WMS_VER}")
    constant(value="\",\"host\":\"")      property(name="hostname")
    constant(value="\",\"severity\":\"")  property(name="syslogseverity-text")
    constant(value="\",\"facility\":\"")  property(name="syslogfacility-text")
    constant(value="\",\"message\":\"Debug table in debug variable\",")
    constant(value="\"debug\":")   property(name="msg")
    constant(value=",\"program\":\"")   property(name="programname" format="json")
    constant(value="\",\"procid\":\"")    property(name="procid")
    constant(value="\",\"time\":\"")      property(name="timegenerated" dateFormat="rfc3339")
    constant(value="\",\"tag\":\"")       property(name="syslogtag" format="json")
    constant(value="\"}\n")
}


if ( \$programname == "luatable" ) then {
        action(type="omfwd"
               Target="${LOG_SERVER}"
               Port="514"
               Protocol="udp"
               template="json-lua-debug"
         )
         stop
} else if ( \$programname != "lualocal" ) then {
        action(type="omfwd"
               Target="${LOG_SERVER}"
               Port="514"
               Protocol="udp"
               template="json-template"
         )
         stop
}
EOF

